' --------------------------------------------------------------------
' Name:         ExamplePowerPointExport
'
' Copyright(c): National Instruments (Ireland) Limited
'
' Zweck:        Writes DIAdem graphics into PowerPoint
' ---------------------------------------------------------------------

Option Explicit

'----------------------------------------------------------------------
' Constants and variables
'----------------------------------------------------------------------

Const csFileNamePPT = "ExamplePowerPointGraphics"

Dim sGlobAutoPath 

'----------------------------------------------------------------------
' Main block
'----------------------------------------------------------------------

call ExampleInit()               ' Initialize
call ExampleReportLoad()         ' Load DIAdem example report
call ExampleReportToExtFormat()  ' Generated an external WMF format
call GraphicsToPowerPoint()      ' Main procedure for generating a PowerPoint
                                 ' file with the example graphics

'----------------------------------------------------------------------
' Procedures
'----------------------------------------------------------------------

'----------------------------------------------------------------------
' Initialize the example
Public Sub ExampleInit()
  sGlobAutoPath = AutoActPath 
  
  ' Check the external WMF file  
  if FilEx(sGlobAutoPath & csFileNamePPT & ".WMF") then
    ' Delete the external WMF file  
    Call FileDelete(sGlobAutoPath & csFileNamePPT & ".WMF", 0) 
  end if 
End Sub

'----------------------------------------------------------------------
' Imports a example template into DIAdem   
Public Sub ExampleReportLoad()
  ' Load example file into DIAdem
  Call DataLoad(DataDrvLibr & "Example.Dat")
  ' Load example template into DIAdem
  Call PicLoad(AutoActPath & "ExamplePowerPointTemplate.LPD")
  ' Update graphic
  Call PicUpdate()
End Sub

'----------------------------------------------------------------------
' Generate an external WMF format from the DIAdem graphics file  
Public Sub ExampleReportToExtFormat()
  Const ciHeight = 351
  Const ciWidth  = 501

  ' Check the external WMF file  
  if not FilEx(sGlobAutoPath & csFileNamePPT & ".WMF") then 
    ' Generate an external WMF format from the DIAdem graphics file   
    Call PicExport(sGlobAutoPath & csFileNamePPT,"WMF",1,ciHeight,ciWidth,"RGB 24 YUV 444",100,"NoCompression",0)
  end if
End Sub

'----------------------------------------------------------------------
' Main procedure for generating a Power Point file with the example graphics
Public Sub GraphicsToPowerPoint
  Const cppWindowMaximized = 3 'Hex: 3
  Const cWmfExtension      = ".wmf"
  Const cExpand            = 48
  Const cTop               = 29
  Const cLeft              = 38

  Dim oPPTM, sgPPTFileM, oSlideM, lIndexM
  Dim oPresentationT, I
  Dim oSlideMaster,lMasterWidth,lMasterHeight
  Dim sgTempPathT, sgDefPictureM, sgPictureM,sgTitleM,sgPPTTemplateM, sgSourceFile
  Dim lTop,lLeft,lWidth,lHeight
  
  '-------------------------------------------------
  ' Set the file name for the Powerpoint file that is
  ' to be used as a template, and copy it to the 
  ' target directory.
  '-------------------------------------------------
  sgPPTTemplateM = AutoActPath & csFileNamePPT & ".ppt"
  sgSourceFile   = AutoActPath & "ExamplePowerPointTemplate.ppt"

  if not PowerPointTemplateCopy(sgSourceFile, AutoActPath, csFileNamePPT & ".ppt") then _
    Exit Sub
  
  if not FilEx(sgPPTTemplateM) then
    Call MsgBoxDisp(MessageTxtGet(2,sgPPTTemplateM))
  else
    '-------------------------------------------------
    ' Set the file name for the Powerpoint file 
    ' that is to be saved as the example file
    '-------------------------------------------------
    sgPPTFileM = sgPPTTemplateM
    
    '-------------------------------------------------
    ' Start Powerpoint and load the template
    '-------------------------------------------------
    Call PPTPresentationLoad(oPPTM,sgPPTTemplateM)
    
    '-------------------------------------------------
    ' Define the page size so the size of the graphics
    ' can be set accordingly
    '-------------------------------------------------
    Set oSlideMaster = oPPTM.ActivePresentation.SlideMaster

    lMasterWidth  = oSlideMaster.Width
    lMasterHeight = oSlideMaster.Height
    lHeight       = (lMasterHeight*.65) + cExpand
    lWidth        = (lHeight / 0.7) + CExpand
    lTop          = cTop
    lLeft         = cLeft

    '-------------------------------------------------
    ' Imports the example graphics generated by DIAdem
    '-------------------------------------------------
    sgTitleM = MessageTxtGet(5,"")
    call PPTTitleSet(oPPTM,sgTitleM)
    
    ' Only add graphic if the layout file exists
    if FilEx(AutoActPath & csFileNamePPT & cWmfExtension) then
        
      sgPictureM = AutoActPath & csFileNamePPT & cWmfExtension
        
      ' Set slide headings and add new slides :
      sgTitleM    = MessageTxtGet(3,"")
      Set oSlideM = PPTPageAdd(oPPTM,sgTitleM,csFileNamePPT)
        
      ' Add diagram generated by DIAdem :
      Call oSlideM.Shapes.AddPicture(sgPictureM,false,true,lLeft,lTop,lWidth,lHeight)

    end if
 
    Call WndShow("SHELL", "MINIMIZE")

    oPPTM.Visible     = True
    oPPTM.WindowState = cppWindowMaximized

    'Dialog-controlled return to the DIAdem application -> Include bottom code in document 
    'If MsgBox(MessageTxtGet(1,""), vbYesNo Or vbQuestion, "Information") = vbYes Then
    '  Call oPPTM.Quit()
    '  Call WndShow("SHELL", "Maximize")
    'end if  
  
    '-------------------------------------------------
    ' Final clean up ...
    '-------------------------------------------------
    Set oSlideMaster = Nothing
    Set oSlideM = Nothing
    Set oPPTM   = Nothing

  end if
  
end sub

'----------------------------------------------------------------------
' Returns the related text when a text number is entered. 
Private Function MessageTxtGet(MsgTxtIndex, sParam)
   Dim sMsgTxt

   MessageTxtGet = ""
   Select case MsgTxtIndex
     case 1 
       sMsgTxt = "Close PowerPoint?"
                 
     case 2
       sMsgTxt = "The PowerPoint file < " & sParam & " > " & VbCrLf & _
                 "could not be created!" & VbCrLf & VbCrLf & _
                 "Please check write rights for path"
     case 3
       sMsgTxt = "DIAdem Example Graphic to PowerPoint"
    
     case 4
       sMsgTxt = "Cannot generate another copy of the Powerpoint template!" & VbCrLf & _
                 "Please close the Powerpoint file in use."
 
     case 5
       sMsgTxt = "DIAdem PowerPoint Example" & VbCrLf & sParam
 
   end Select 
   MessageTxtGet = sMsgTxt
   
end Function

'----------------------------------------------------------------------
' Procedure for setting the title on the first slide
Private Sub PPTTitleSet(oPPT,sgTitle)
  Dim oTitleSlide
  
  ' Update connection ...
  Call PPTConnectUpdate(oPPT)

  ' Open title slide (first slide in the template)
  Set oTitleSlide = oPPT.ActivePresentation.Slides(1)

  ' Update the title
  if ( 0 < Len(sgTitle) ) Then _
    oTitleSlide.Shapes.Title.TextFrame.TextRange.Text = sgTitle

  Set oTitleSlide = Nothing
End Sub

'----------------------------------------------------------------------
' Procedure for generating a new slide in Powerpoint and setting the
' slide title
Private Function PPTPageAdd(oPPT,sgTitle,sgGraphic)
  Dim  lIndexT,oSlideT

  ' Update connection ...
  Call PPTConnectUpdate(oPPT)

  ' Specify the number for a new slide
  lIndexT = oPPT.ActivePresentation.Slides.Count+1

  ' Generate the slide
  Set oSlideT = oPPT.ActivePresentation.Slides.Add(lIndexT,2)

  ' Update the graphic file name
  if ( 0 < Len(sgGraphic) ) Then _
    oSlideT.Shapes.Title.TextFrame.TextRange.Text = sgGraphic

  Set PPTPageAdd = oSlideT
End Function

'----------------------------------------------------------------------
' Start PowerPoint and load the template
Private Function  PPTPresentationLoad(oPPT,sgFilename)
  const cppWindowMinimized = 2 'Hex: 2
  
  'Update connection ...
  Call PPTConnectUpdate(oPPT)
  oPPT.Visible = True
  oPPT.WindowState = cppWindowMinimized
  Set PPTPresentationLoad = oPPT.Presentations.Open(sgFilename)
End Function

'----------------------------------------------------------------------
' Update PowerPoint connection
Private Sub PPTConnectUpdate(oPPT)
  if ( vbEmpty = VarType(oPPT) ) Then
    Set oPPT = CreateObject("Powerpoint.Application")
  end if  
End Sub

'----------------------------------------------------------------------
' Copies the PowerPoint template into a example report template. A 
' message is displayed when errors occur. 
Private Function PowerPointTemplateCopy(sSourceFile, sTargetPath, sTargetFileName)
    const csPptExt = ".ppt"
    
    Dim bError
    Dim sTargetFileTmpNoExt, sTargetFileTmp 

    PowerPointTemplateCopy = True
   
    sTargetFileTmp = sTargetFileName
    sTargetFileTmpNoExt = Left(sTargetFileName , Len(sTargetFileName)-4) 

    On Error Resume next
      call FileCopy(sSourceFile, sTargetPath & sTargetFileTmp)
      bError = not (Err.Number = 0)
    On Error Goto 0
    
    if bError then
      sTargetFileTmp = sTargetFileTmpNoExt & csPptExt
      Call MsgBoxDisp(MessageTxtGet(4,"")) 
      Err.Clear
      PowerPointTemplateCopy = False
    end if

end Function

